Add parser/action support for block literal expressions.
Parser support for blocks is almost complete...just need to add support for the __block() storage class qualifier.


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@55495 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/AST/ASTContext.cpp b/lib/AST/ASTContext.cpp
index a4b54f2..ad82090 100644
--- a/lib/AST/ASTContext.cpp
+++ b/lib/AST/ASTContext.cpp
@@ -613,8 +613,8 @@
 /// getBlockPointerType - Return the uniqued reference to the type for 
 /// a pointer to the specified block.
 QualType ASTContext::getBlockPointerType(QualType T) {
-  assert(T->isFunctionType() && "closure of function types only");
-  // Unique pointers, to guarantee there is only one closure of a particular
+  assert(T->isFunctionType() && "block of function types only");
+  // Unique pointers, to guarantee there is only one block of a particular
   // structure.
   llvm::FoldingSetNodeID ID;
   BlockPointerType::Profile(ID, T);
@@ -624,7 +624,7 @@
         BlockPointerTypes.FindNodeOrInsertPos(ID, InsertPos))
     return QualType(PT, 0);
   
   // If the closure pointee type isn't canonical, this won't be a canonical 
   // type either so fill in the canonical type field.
   QualType Canonical;
   if (!T->isCanonical()) {
@@ -624,7 +624,7 @@
     return QualType(PT, 0);
   
-  // If the closure pointee type isn't canonical, this won't be a canonical 
+  // If the block pointee type isn't canonical, this won't be a canonical 
   // type either so fill in the canonical type field.
   QualType Canonical;